@@ -1,5 +1,9 @@
 package hostsensorutils
 
+import (
+	"github.com/armosec/opa-utils/objectsenvelopes/hostsensor"
+)
+
 type HostSensorHandlerMock struct {
 }
 
@@ -11,8 +15,8 @@ func (hshm *HostSensorHandlerMock) TearDown() error {
 	return nil
 }
 
-func (hshm *HostSensorHandlerMock) CollectResources() ([]HostSensorDataEnvelope, error) {
-	return []HostSensorDataEnvelope{}, nil
+func (hshm *HostSensorHandlerMock) CollectResources() ([]hostsensor.HostSensorDataEnvelope, error) {
+	return []hostsensor.HostSensorDataEnvelope{}, nil
 }
 
 func (hshm *HostSensorHandlerMock) GetNamespace() string {
